Glossary
========

.. glossary::

  PEP
    PEP stands for Python Enhancement Proposal.
    A PEP is a design document providing information to the Python community,
    or describing a new feature for Python or its processes or environment.
    The PEP should provide a concise technical specification of the feature
    and a rationale for the feature.
    https://www.python.org/dev/peps/pep-0001/#what-is-a-pep
